@@ -5,6 +5,7 @@ from typing import (
     Generator,
     Generic,
     Iterable,
+    List,
     Mapping,
     Sequence,
     TypeVar,
@@ -21,7 +22,7 @@ import optuna.integration.lightgbm
 from ._common import logger
 
 
-__version__ = "0.9.0"
+__version__ = "0.9.1"
 _T1 = TypeVar("_T1")
 
 
@@ -88,8 +89,8 @@ def train_lightgbm_v1(
     params_hpo: Mapping[str, Any],
     kwargs_hpo: Mapping[str, Any],
 ) -> Dict[str, Any]:
-    params_best = dict()
-    tuning_history = []
+    params_best: Dict[str, Any] = dict()
+    tuning_history: List[Any] = []
     with timing_v1("Run optuna.integration.lightgbm.train: %s", logger.debug):
         model_hpo = optuna.integration.lightgbm.train(
             params_hpo,
@@ -127,7 +128,7 @@ def intersect1d_v1(xss: Sequence[Sequence[_T1]], assume_unique=False) -> Sequenc
         return ret
 
 
-def batch_v1(xs: Iterable[_T1], n: int) -> Generator[_T1, None, None]:
+def batch_v1(xs: Iterable[_T1], n: int) -> Generator[List[_T1], None, None]:
     if n < 1:
         raise ValueError(f"`n` should be >= 1: {n}")
     range_n = range(n)
@@ -144,7 +145,7 @@ def intersect_sorted_arrays_v1(xss):
     if n_xss <= 0:
         return []
     elif n_xss == 1:
-        return xss[0]
+        return _uniq_sorted_array_v1(xss[0])
     else:
         if len(xss[0]) <= 0:
             return []
@@ -200,3 +201,20 @@ def _skip_le_v1(xs, i, n, x_max):
             break
         i += 1
     return i
+
+
+@numba.njit(nogil=True, cache=True)
+def _uniq_sorted_array_v1(xs):
+    ret = []
+    n_xs = len(xs)
+    if n_xs == 0:
+        return ret
+    x = xs[0]
+    ret.append(x)
+    seen = x
+    for i in range(1, n_xs):
+        x = xs[i]
+        if x != seen:
+            ret.append(x)
+            seen = x
+    return ret
